@@ -1,8 +1,5 @@
 package App::Cerberus;
-{
-  $App::Cerberus::VERSION = '0.10';
-}
-
+$App::Cerberus::VERSION = '0.11';
 use strict;
 use warnings;
 use JSON();
@@ -63,17 +60,19 @@ sub request {
 
 # ABSTRACT: A pluggable Perl web service to preprocess web requests. Plugins can add geo, timezone and browser metadata, and throttle request rate.
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Cerberus - A pluggable Perl web service to preprocess web requests. Plugins can add geo, timezone and browser metadata, and throttle request rate.
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -159,14 +158,15 @@ For instance:
 
     "ua": {
         "is_robot": 0,
-        "is_mobile": 1,
+        "is_mobile": 0,
+        "is_tablet": 1,
         "version": {
             "minor": ".1",
             "full": 5.1,
             "major": "5"
         },
         "browser": "safari",
-        "device": "iphone",
+        "device": "ipad",
         "browser_properties": [
             "ios",
             "iphone",
@@ -296,10 +296,9 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Clinton Gormley.
+This software is copyright (c) 2014 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
